diff mbox

FYI: 1500+ typos, with suggested fixes

Message ID Pine.LNX.4.64.1205291454550.16901@digraph.polyomino.org.uk
State New
Headers show

Commit Message

Joseph Myers May 29, 2012, 3:01 p.m. UTC
On Tue, 29 May 2012, Jim Meyering wrote:

> sed -i '167s!Millenial!Millennial!' libgcc/config/libbid/bid128_string.c
> sed -i '30s!guranteed!guaranteed!' libgcc/config/libbid/bid64_fma.c
> sed -i '174s!oposite!opposite!' libgcc/config/libbid/bid64_fma.c
> sed -i '218s!oposite!opposite!' libgcc/config/libbid/bid64_fma.c
> sed -i '154s!Millenial!Millennial!' libgcc/config/libbid/bid64_string.c
> sed -i '1825s!pased!passed!' libgcc/config/libbid/bid_internal.h

libbid is also externally maintained, see 
<http://gcc.gnu.org/codingconventions.html>.

I've applied this patch with fixes for some of the more straightforward 
issues in the rest of libgcc and in libcpp.

I suggest sending an updated typo list for current sources - minus the 
parts for directories identified as maintained elsewhere, and possibly 
split by directory - as smaller lists are easier for people to go through.  
For libjava and gcc/java changes, CC java@gcc.gnu.org on the list (they 
may well be able to deal with the classpath typos although properly it's a 
separate project).  For libstdc++-v3 changes (other than 
libstdc++-v3/doc/html/ext/ which are files from WG21), CC 
libstdc++@gcc.gnu.org.

Comments

Joseph Myers May 29, 2012, 3:02 p.m. UTC | #1
On Tue, 29 May 2012, Joseph S. Myers wrote:

> For libjava and gcc/java changes, CC java@gcc.gnu.org on the list (they 
> may well be able to deal with the classpath typos although properly it's a 
> separate project).  For libstdc++-v3 changes (other than 
> libstdc++-v3/doc/html/ext/ which are files from WG21), CC 
> libstdc++@gcc.gnu.org.

Also, for changes to gcc/fortran/ and libgfortran/, CC 
fortran@gcc.gnu.org.
diff mbox

Patch

Index: libgcc/configure.ac
===================================================================
--- libgcc/configure.ac	(revision 187963)
+++ libgcc/configure.ac	(working copy)
@@ -315,7 +315,7 @@ 
 AC_SUBST(vis_hide)
 
 # See if we have thread-local storage.  We can only test assembler
-# sicne link-time and run-time tests require the newly built
+# since link-time and run-time tests require the newly built
 # gcc, which can't be used to build executable due to that libgcc
 # is yet to be built here.
 GCC_CHECK_CC_TLS
Index: libgcc/ChangeLog
===================================================================
--- libgcc/ChangeLog	(revision 187963)
+++ libgcc/ChangeLog	(working copy)
@@ -1,3 +1,33 @@ 
+2012-05-29  Joseph Myers  <joseph@codesourcery.com>
+
+	* config/arm/ieee754-df.S: Fix typos.
+	* config/arm/ieee754-sf.S: Fix typos.
+	* config/c6x/libunwind.S: Fix typos.
+	* config/epiphany/udivsi3-float.c: Fix typos.
+	* config/microblaze/muldi3_hard.S: Fix typos.
+	* config/picochip/adddi3.S: Fix typos.
+	* config/picochip/ashlsi3.S: Fix typos.
+	* config/picochip/ashrsi3.S: Fix typos.
+	* config/picochip/clzsi2.S: Fix typos.
+	* config/picochip/cmpsi2.S: Fix typos.
+	* config/picochip/divmod15.S: Fix typos.
+	* config/picochip/divmodhi4.S: Fix typos.
+	* config/picochip/divmodsi4.S: Fix typos.
+	* config/picochip/longjmp.S: Fix typos.
+	* config/picochip/lshrsi3.S: Fix typos.
+	* config/picochip/parityhi2.S: Fix typos.
+	* config/picochip/popcounthi2.S: Fix typos.
+	* config/picochip/setjmp.S: Fix typos.
+	* config/picochip/subdi3.S: Fix typos.
+	* config/picochip/ucmpsi2.S: Fix typos.
+	* config/picochip/udivmodhi4.S: Fix typos.
+	* config/picochip/udivmodsi4.S: Fix typos.
+	* config/spu/divv2df3.c: Fix typos.
+	* config/spu/mfc_multi_tag_release.c: Fix typos.
+	* config/spu/mfc_tag_release.c: Fix typos.
+	* configure.ac: Fix typos.
+	* configure: Regenerate.
+
 2012-05-25  Ian Lance Taylor  <iant@google.com>
 
 	* config/i386/morestack.S (__morestack_non_split): Check whether
Index: libgcc/config/c6x/libunwind.S
===================================================================
--- libgcc/config/c6x/libunwind.S	(revision 187963)
+++ libgcc/config/c6x/libunwind.S	(working copy)
@@ -113,7 +113,7 @@ 
 	# Zero demand saved flags
 	mvk	.s1	0, A0
 	stw	.d2t1	A0, *+B15[1]
-	# Save return address, setup additional argument and call fucntion
+	# Save return address, setup additional argument and call function
 	stw	.d2t2	B3, *+B15[35]
 	add	.d\argside	B15, 4, \argreg
 	do_call	__gnu\name
Index: libgcc/config/spu/mfc_tag_release.c
===================================================================
--- libgcc/config/spu/mfc_tag_release.c	(revision 187963)
+++ libgcc/config/spu/mfc_tag_release.c	(working copy)
@@ -25,7 +25,7 @@ 
 extern vector unsigned int __mfc_tag_table;
 
 /* Release the specified DMA tag from exclusive use.  Once released, the
-   tag is available for future reservation.  Upon sucessful release,
+   tag is available for future reservation.  Upon successful release,
    MFC_DMA_TAG_VALID is returned.  If the specified tag is not in the
    range 0 to 31, or had not been reserved, no action is taken and
    MFC_DMA_TAG_INVALID is returned.  */
Index: libgcc/config/spu/mfc_multi_tag_release.c
===================================================================
--- libgcc/config/spu/mfc_multi_tag_release.c	(revision 187963)
+++ libgcc/config/spu/mfc_multi_tag_release.c	(working copy)
@@ -26,7 +26,7 @@ 
 
 /* Release a sequential group of tags from exclusive use. The sequential
    group of tags is the range starting from <first_tag> through
-   <first_tag>+<number_of_tags>-1. Upon sucessful release, MFC_DMA_TAG_VALID
+   <first_tag>+<number_of_tags>-1. Upon successful release, MFC_DMA_TAG_VALID
    is returned and the tags become available for future reservation.
 
    If the specified tags were not previously reserved, no action is
Index: libgcc/config/spu/divv2df3.c
===================================================================
--- libgcc/config/spu/divv2df3.c	(revision 187963)
+++ libgcc/config/spu/divv2df3.c	(working copy)
@@ -77,7 +77,7 @@ 
   a_exp_1s = (vec_ullong2)spu_cmpeq(a_exp, exp_mask_u32);
   b_exp_1s = (vec_ullong2)spu_cmpeq(b_exp, exp_mask_u32);
 
-  /* Identify all possible special values that must be accomodated including:
+  /* Identify all possible special values that must be accommodated including:
    * +-denorm, +-0, +-infinity, and NaNs.
    */
   a_denorm0= (vec_ullong2)spu_cmpeq(a_exp, 0);
Index: libgcc/config/picochip/ucmpsi2.S
===================================================================
--- libgcc/config/picochip/ucmpsi2.S	(revision 187963)
+++ libgcc/config/picochip/ucmpsi2.S	(working copy)
@@ -77,7 +77,7 @@ 
 // All DWARF information between this marker, and the END OF DWARF
 // marker should be included in the source file. Search for
 // FUNCTION_STACK_SIZE_GOES_HERE and FUNCTION NAME GOES HERE, and
-// provide the relevent information. Add markers called
+// provide the relevant information. Add markers called
 // _picoMark_FUNCTION_BEGIN and _picoMark_FUNCTION_END around the
 // function in question.
 //============================================================================
Index: libgcc/config/picochip/lshrsi3.S
===================================================================
--- libgcc/config/picochip/lshrsi3.S	(revision 187963)
+++ libgcc/config/picochip/lshrsi3.S	(working copy)
@@ -59,7 +59,7 @@ 
 // All DWARF information between this marker, and the END OF DWARF
 // marker should be included in the source file. Search for
 // FUNCTION_STACK_SIZE_GOES_HERE and FUNCTION NAME GOES HERE, and
-// provide the relevent information. Add markers called
+// provide the relevant information. Add markers called
 // _picoMark_FUNCTION_BEGIN and _picoMark_FUNCTION_END around the
 // function in question.
 //============================================================================
Index: libgcc/config/picochip/divmodhi4.S
===================================================================
--- libgcc/config/picochip/divmodhi4.S	(revision 187963)
+++ libgcc/config/picochip/divmodhi4.S	(working copy)
@@ -115,7 +115,7 @@ 
 // All DWARF information between this marker, and the END OF DWARF
 // marker should be included in the source file. Search for
 // FUNCTION_STACK_SIZE_GOES_HERE and FUNCTION NAME GOES HERE, and
-// provide the relevent information. Add markers called
+// provide the relevant information. Add markers called
 // _picoMark_FUNCTION_BEGIN and _picoMark_FUNCTION_END around the
 // function in question.
 //============================================================================
Index: libgcc/config/picochip/udivmodsi4.S
===================================================================
--- libgcc/config/picochip/udivmodsi4.S	(revision 187963)
+++ libgcc/config/picochip/udivmodsi4.S	(working copy)
@@ -186,7 +186,7 @@ 
 // All DWARF information between this marker, and the END OF DWARF
 // marker should be included in the source file. Search for
 // FUNCTION_STACK_SIZE_GOES_HERE and FUNCTION NAME GOES HERE, and
-// provide the relevent information. Add markers called
+// provide the relevant information. Add markers called
 // _picoMark_FUNCTION_BEGIN and _picoMark_FUNCTION_END around the
 // function in question.
 //============================================================================
Index: libgcc/config/picochip/divmod15.S
===================================================================
--- libgcc/config/picochip/divmod15.S	(revision 187963)
+++ libgcc/config/picochip/divmod15.S	(working copy)
@@ -128,7 +128,7 @@ 
 // All DWARF information between this marker, and the END OF DWARF
 // marker should be included in the source file. Search for
 // FUNCTION_STACK_SIZE_GOES_HERE and FUNCTION NAME GOES HERE, and
-// provide the relevent information. Add markers called
+// provide the relevant information. Add markers called
 // _picoMark_FUNCTION_BEGIN and _picoMark_FUNCTION_END around the
 // function in question.
 //============================================================================
Index: libgcc/config/picochip/adddi3.S
===================================================================
--- libgcc/config/picochip/adddi3.S	(revision 187963)
+++ libgcc/config/picochip/adddi3.S	(working copy)
@@ -62,7 +62,7 @@ 
 // All DWARF information between this marker, and the END OF DWARF
 // marker should be included in the source file. Search for
 // FUNCTION_STACK_SIZE_GOES_HERE and FUNCTION NAME GOES HERE, and
-// provide the relevent information. Add markers called
+// provide the relevant information. Add markers called
 // _picoMark_FUNCTION_BEGIN and _picoMark_FUNCTION_END around the
 // function in question.
 //============================================================================
Index: libgcc/config/picochip/subdi3.S
===================================================================
--- libgcc/config/picochip/subdi3.S	(revision 187963)
+++ libgcc/config/picochip/subdi3.S	(working copy)
@@ -59,7 +59,7 @@ 
 // All DWARF information between this marker, and the END OF DWARF
 // marker should be included in the source file. Search for
 // FUNCTION_STACK_SIZE_GOES_HERE and FUNCTION NAME GOES HERE, and
-// provide the relevent information. Add markers called
+// provide the relevant information. Add markers called
 // _picoMark_FUNCTION_BEGIN and _picoMark_FUNCTION_END around the
 // function in question.
 //============================================================================
Index: libgcc/config/picochip/cmpsi2.S
===================================================================
--- libgcc/config/picochip/cmpsi2.S	(revision 187963)
+++ libgcc/config/picochip/cmpsi2.S	(working copy)
@@ -79,7 +79,7 @@ 
 // All DWARF information between this marker, and the END OF DWARF
 // marker should be included in the source file. Search for
 // FUNCTION_STACK_SIZE_GOES_HERE and FUNCTION NAME GOES HERE, and
-// provide the relevent information. Add markers called
+// provide the relevant information. Add markers called
 // _picoMark_FUNCTION_BEGIN and _picoMark_FUNCTION_END around the
 // function in question.
 //============================================================================
Index: libgcc/config/picochip/divmodsi4.S
===================================================================
--- libgcc/config/picochip/divmodsi4.S	(revision 187963)
+++ libgcc/config/picochip/divmodsi4.S	(working copy)
@@ -100,7 +100,7 @@ 
 // All DWARF information between this marker, and the END OF DWARF
 // marker should be included in the source file. Search for
 // FUNCTION_STACK_SIZE_GOES_HERE and FUNCTION NAME GOES HERE, and
-// provide the relevent information. Add markers called
+// provide the relevant information. Add markers called
 // _picoMark_FUNCTION_BEGIN and _picoMark_FUNCTION_END around the
 // function in question.
 //============================================================================
Index: libgcc/config/picochip/setjmp.S
===================================================================
--- libgcc/config/picochip/setjmp.S	(revision 187963)
+++ libgcc/config/picochip/setjmp.S	(working copy)
@@ -49,7 +49,7 @@ 
 // All DWARF information between this marker, and the END OF DWARF
 // marker should be included in the source file. Search for
 // FUNCTION_STACK_SIZE_GOES_HERE and FUNCTION NAME GOES HERE, and
-// provide the relevent information. Add markers called
+// provide the relevant information. Add markers called
 // _picoMark_FUNCTION_BEGIN and _picoMark_FUNCTION_END around the
 // function in question.
 //============================================================================
Index: libgcc/config/picochip/clzsi2.S
===================================================================
--- libgcc/config/picochip/clzsi2.S	(revision 187963)
+++ libgcc/config/picochip/clzsi2.S	(working copy)
@@ -56,7 +56,7 @@ 
 // All DWARF information between this marker, and the END OF DWARF
 // marker should be included in the source file. Search for
 // FUNCTION_STACK_SIZE_GOES_HERE and FUNCTION NAME GOES HERE, and
-// provide the relevent information. Add markers called
+// provide the relevant information. Add markers called
 // _picoMark_FUNCTION_BEGIN and _picoMark_FUNCTION_END around the
 // function in question.
 //============================================================================
Index: libgcc/config/picochip/longjmp.S
===================================================================
--- libgcc/config/picochip/longjmp.S	(revision 187963)
+++ libgcc/config/picochip/longjmp.S	(working copy)
@@ -49,7 +49,7 @@ 
 // All DWARF information between this marker, and the END OF DWARF
 // marker should be included in the source file. Search for
 // FUNCTION_STACK_SIZE_GOES_HERE and FUNCTION NAME GOES HERE, and
-// provide the relevent information. Add markers called
+// provide the relevant information. Add markers called
 // _picoMark_FUNCTION_BEGIN and _picoMark_FUNCTION_END around the
 // function in question.
 //============================================================================
Index: libgcc/config/picochip/ashlsi3.S
===================================================================
--- libgcc/config/picochip/ashlsi3.S	(revision 187963)
+++ libgcc/config/picochip/ashlsi3.S	(working copy)
@@ -61,7 +61,7 @@ 
 // All DWARF information between this marker, and the END OF DWARF
 // marker should be included in the source file. Search for
 // FUNCTION_STACK_SIZE_GOES_HERE and FUNCTION NAME GOES HERE, and
-// provide the relevent information. Add markers called
+// provide the relevant information. Add markers called
 // _picoMark_FUNCTION_BEGIN and _picoMark_FUNCTION_END around the
 // function in question.
 //============================================================================
Index: libgcc/config/picochip/popcounthi2.S
===================================================================
--- libgcc/config/picochip/popcounthi2.S	(revision 187963)
+++ libgcc/config/picochip/popcounthi2.S	(working copy)
@@ -68,7 +68,7 @@ 
 // All DWARF information between this marker, and the END OF DWARF
 // marker should be included in the source file. Search for
 // FUNCTION_STACK_SIZE_GOES_HERE and FUNCTION NAME GOES HERE, and
-// provide the relevent information. Add markers called
+// provide the relevant information. Add markers called
 // _picoMark_FUNCTION_BEGIN and _picoMark_FUNCTION_END around the
 // function in question.
 //============================================================================
Index: libgcc/config/picochip/parityhi2.S
===================================================================
--- libgcc/config/picochip/parityhi2.S	(revision 187963)
+++ libgcc/config/picochip/parityhi2.S	(working copy)
@@ -46,7 +46,7 @@ 
 // All DWARF information between this marker, and the END OF DWARF
 // marker should be included in the source file. Search for
 // FUNCTION_STACK_SIZE_GOES_HERE and FUNCTION NAME GOES HERE, and
-// provide the relevent information. Add markers called
+// provide the relevant information. Add markers called
 // _picoMark_FUNCTION_BEGIN and _picoMark_FUNCTION_END around the
 // function in question.
 //============================================================================
Index: libgcc/config/picochip/ashrsi3.S
===================================================================
--- libgcc/config/picochip/ashrsi3.S	(revision 187963)
+++ libgcc/config/picochip/ashrsi3.S	(working copy)
@@ -69,7 +69,7 @@ 
 // All DWARF information between this marker, and the END OF DWARF
 // marker should be included in the source file. Search for
 // FUNCTION_STACK_SIZE_GOES_HERE and FUNCTION NAME GOES HERE, and
-// provide the relevent information. Add markers called
+// provide the relevant information. Add markers called
 // _picoMark_FUNCTION_BEGIN and _picoMark_FUNCTION_END around the
 // function in question.
 //============================================================================
Index: libgcc/config/picochip/udivmodhi4.S
===================================================================
--- libgcc/config/picochip/udivmodhi4.S	(revision 187963)
+++ libgcc/config/picochip/udivmodhi4.S	(working copy)
@@ -106,7 +106,7 @@ 
 // All DWARF information between this marker, and the END OF DWARF
 // marker should be included in the source file. Search for
 // FUNCTION_STACK_SIZE_GOES_HERE and FUNCTION NAME GOES HERE, and
-// provide the relevent information. Add markers called
+// provide the relevant information. Add markers called
 // _picoMark_FUNCTION_BEGIN and _picoMark_FUNCTION_END around the
 // function in question.
 //============================================================================
Index: libgcc/config/arm/ieee754-df.S
===================================================================
--- libgcc/config/arm/ieee754-df.S	(revision 187963)
+++ libgcc/config/arm/ieee754-df.S	(working copy)
@@ -922,7 +922,7 @@ 
 	teqne	r5, ip
 	bleq	LSYM(Ldv_s)
 
-	@ Substract divisor exponent from dividend''s.
+	@ Subtract divisor exponent from dividend''s.
 	sub	r4, r4, r5
 
 	@ Preserve final sign into lr.
@@ -956,7 +956,7 @@ 
 	movs	yh, yh, lsr #1
 	mov	yl, yl, rrx
 1:
-	@ Perform first substraction to align result to a nibble.
+	@ Perform first subtraction to align result to a nibble.
 	subs	r6, r6, yl
 	sbc	r5, r5, yh
 	movs	yh, yh, lsr #1
Index: libgcc/config/arm/ieee754-sf.S
===================================================================
--- libgcc/config/arm/ieee754-sf.S	(revision 187963)
+++ libgcc/config/arm/ieee754-sf.S	(working copy)
@@ -661,7 +661,7 @@ 
 	beq	LSYM(Ldv_s)
 LSYM(Ldv_x):
 
-	@ Substract divisor exponent from dividend''s
+	@ Subtract divisor exponent from dividend''s
 	sub	r2, r2, r3
 
 	@ Preserve final sign into ip.
Index: libgcc/config/microblaze/muldi3_hard.S
===================================================================
--- libgcc/config/microblaze/muldi3_hard.S	(revision 187963)
+++ libgcc/config/microblaze/muldi3_hard.S	(working copy)
@@ -68,7 +68,7 @@ 
 	swi	r26,r1,24
 	swi	r27,r1,28
 
-# Load all the 16 bit values for A thru H
+# Load all the 16 bit values for A through H
 	lhui	r20,r1,44   # A
 	lhui	r21,r1,46   # B
 	lhui	r22,r1,48   # C
Index: libgcc/config/epiphany/udivsi3-float.c
===================================================================
--- libgcc/config/epiphany/udivsi3-float.c	(revision 187963)
+++ libgcc/config/epiphany/udivsi3-float.c	(working copy)
@@ -40,7 +40,7 @@ 
 
   /* Assuming B is nonzero, compute S0 such that 0 <= S0,
      (B << S0+1) does not overflow,
-     A < 4.01 * (B << S0), with S0 choosen as small as possible
+     A < 4.01 * (B << S0), with S0 chosen as small as possible
      without taking to much time calculating.  */
 #ifdef CONVERT_UNSIGNED
   u0.f = a;
Index: libgcc/configure
===================================================================
--- libgcc/configure	(revision 187963)
+++ libgcc/configure	(working copy)
@@ -4358,7 +4358,7 @@ 
 
 
 # See if we have thread-local storage.  We can only test assembler
-# sicne link-time and run-time tests require the newly built
+# since link-time and run-time tests require the newly built
 # gcc, which can't be used to build executable due to that libgcc
 # is yet to be built here.
 
Index: libcpp/directives.c
===================================================================
--- libcpp/directives.c	(revision 187963)
+++ libcpp/directives.c	(working copy)
@@ -446,7 +446,7 @@ 
 	 
 	 We exclude the -fdirectives-only case because macro expansion
 	 has not been performed yet, and block comments can cause spaces
-	 to preceed the directive.  */
+	 to precede the directive.  */
       if (CPP_OPTION (pfile, preprocessed)
 	  && !CPP_OPTION (pfile, directives_only)
 	  && (indented || !(dir->flags & IN_I)))
Index: libcpp/macro.c
===================================================================
--- libcpp/macro.c	(revision 187963)
+++ libcpp/macro.c	(working copy)
@@ -72,7 +72,7 @@ 
   /* A pointer to the current token pointed to by the iterator.  */
   const cpp_token **token_ptr;
   /* A pointer to the "full" location of the current token.  If
-     -ftrack-macro-expansion is used this location tracks loci accross
+     -ftrack-macro-expansion is used this location tracks loci across
      macro expansion.  */
   const source_location *location_ptr;
 #ifdef ENABLE_CHECKING
@@ -1221,7 +1221,7 @@ 
 
 /* Set the INDEXth token of the macro argument ARG. TOKEN is the token
    to set, LOCATION is its virtual location.  "Virtual" location means
-   the location that encodes loci accross macro expansion. Otherwise
+   the location that encodes loci across macro expansion. Otherwise
    it has to be TOKEN->SRC_LOC.  KIND is the kind of tokens the
    argument ARG is supposed to contain.  Note that ARG must be
    tailored so that it has enough room to contain INDEX + 1 numbers of
@@ -1346,7 +1346,7 @@ 
 
 /* Move the iterator one token forward. Note that if IT was
    initialized on an argument that has a stringified token, moving it
-   foward doesn't make sense as a stringified token is essentially one
+   forward doesn't make sense as a stringified token is essentially one
    string.  */
 static void
 macro_arg_token_iter_forward (macro_arg_token_iter *it)
@@ -1965,7 +1965,7 @@ 
    means -ftrack-macro-expansion is effect; it then points to where to
    insert the virtual location of TOKEN.  TOKEN is the token to
    insert.  VIRT_LOC is the virtual location of the token, i.e, the
-   location possibly encoding its locus accross macro expansion.  If
+   location possibly encoding its locus across macro expansion.  If
    TOKEN is an argument of a function-like macro (inside a macro
    replacement list), PARM_DEF_LOC is the spelling location of the
    macro parameter that TOKEN is replacing, in the replacement list of
@@ -2010,7 +2010,7 @@ 
    reaches BUFFER's size; it aborts in that situation.
 
    TOKEN is the token to append. VIRT_LOC is the virtual location of
-   the token, i.e, the location possibly encoding its locus accross
+   the token, i.e, the location possibly encoding its locus across
    macro expansion. If TOKEN is an argument of a function-like macro
    (inside a macro replacement list), PARM_DEF_LOC is the location of
    the macro parameter that TOKEN is replacing.  If TOKEN doesn't come
@@ -2226,7 +2226,7 @@ 
       if (macro != NULL
 	  /* Several contiguous macro expansion contexts can be
 	     associated to the same macro; that means it's the same
-	     macro expansion that spans accross all these (sub)
+	     macro expansion that spans across all these (sub)
 	     contexts.  So we should re-enable an expansion-disabled
 	     macro only when we are sure we are really out of that
 	     macro expansion.  */
@@ -2264,7 +2264,7 @@ 
 /* Consume the next token contained in the current context of PFILE,
    and return it in *TOKEN. It's "full location" is returned in
    *LOCATION. If -ftrack-macro-location is in effeect, fFull location"
-   means the location encoding the locus of the token accross macro
+   means the location encoding the locus of the token across macro
    expansion; otherwise it's just is the "normal" location of the
    token which (*TOKEN)->src_loc.  */
 static inline void
Index: libcpp/line-map.c
===================================================================
--- libcpp/line-map.c	(revision 187963)
+++ libcpp/line-map.c	(working copy)
@@ -269,7 +269,7 @@ 
   return map;
 }
 
-/* Returns TRUE if the line table set tracks token locations accross
+/* Returns TRUE if the line table set tracks token locations across
    macro expansion, FALSE otherwise.  */
 
 bool
@@ -1118,7 +1118,7 @@ 
    of a macro M and if its spelling location is reserved (e.g, a
    location for a built-in token), then this function unwinds (using
    linemap_unwind_toward_expansion) the location until a location that
-   is not reserved and is not in a sytem header is reached.  In other
+   is not reserved and is not in a system header is reached.  In other
    words, this unwinds the reserved location until a location that is
    in real source code is reached.
 
Index: libcpp/ChangeLog
===================================================================
--- libcpp/ChangeLog	(revision 187963)
+++ libcpp/ChangeLog	(working copy)
@@ -1,3 +1,10 @@ 
+2012-05-29  Joseph Myers  <joseph@codesourcery.com>
+
+	* directives.c: Fix typos.
+	* include/line-map.h: Fix typos.
+	* line-map.c: Fix typos.
+	* macro.c: Fix typos.
+
 2012-05-25  Dodji Seketeli  <dodji@redhat.com>
 
 	PR bootstrap/53459
Index: libcpp/include/line-map.h
===================================================================
--- libcpp/include/line-map.h	(revision 187963)
+++ libcpp/include/line-map.h	(working copy)
@@ -159,7 +159,7 @@ 
 
      Note that a virtual location is a location returned by
      linemap_add_macro_token.  It encodes the relevant locations (x,y
-     pairs) of that token accross the macro expansions from which it
+     pairs) of that token across the macro expansions from which it
      (the token) might come from.
 
      In the example above x1 (for token "+") is going to be the same
@@ -370,7 +370,7 @@ 
 #define LINEMAPS_LAST_ALLOCATED_ORDINARY_MAP(SET) \
   LINEMAPS_LAST_ALLOCATED_MAP(SET, false)
 
-/* Returns a pointer to the begining of the region where macro maps
+/* Returns a pointer to the beginning of the region where macro maps
    are allcoated.  */
 #define LINEMAPS_MACRO_MAPS(SET) \
   LINEMAPS_MAPS(SET, true)
@@ -450,7 +450,7 @@ 
 extern const struct line_map *linemap_lookup
   (struct line_maps *, source_location);
 
 /* Returns TRUE if the line table set tracks token locations accross
    macro expansion, FALSE otherwise.  */
 bool linemap_tracks_macro_expansion_locs_p (struct line_maps *);
 
@@ -450,7 +450,7 @@ 
   (struct line_maps *, source_location);
 
-/* Returns TRUE if the line table set tracks token locations accross
+/* Returns TRUE if the line table set tracks token locations across
    macro expansion, FALSE otherwise.  */
 bool linemap_tracks_macro_expansion_locs_p (struct line_maps *);